Module docs

Module docs 

Links into the versioned documentation site.

docs.atuin.sh is versioned with mike, and the three kinds of version it publishes are not equally durable (see .github/actions/docs-deploy-*):

TODO(markovejnovic): This file is debt and slop. Probably doesn’t belong in atuin-common even.

Constants

VERSION
The docs.atuin.sh version segment matching this build.

Functions

url
A URL for path (e.g. guide/sync/#login) in this build’s documentation.