RichDisplay

Struct RichDisplay 

pub struct RichDisplay<'a> { /* private fields */ }
A Display adapter for a path with optional enrichments, built via DisplayRichExt::display_rich.

With no options set, the Display output is byte-identical to Path::display. You can also:

  • relative_to: if the path is under base, render relative to base.
  • tilde: if the path is under home, render it as ~ + separator + remainder.
  • trailing_slash: the rendered text ends with the platform separator.

Like Path::display, rendering is lossy for non-UTF-8 paths.

Implementations

Source

impl<'a> RichDisplay<'a>

pub fn trailing_slash(self, enabled: bool) -> Self

pub fn relative_to<P: AsRef<Path> + ?Sized>(self, base: &'a P) -> Self

Render the path relative to base when it is under it. Borrows base for the lifetime of this RichDisplay, so no allocation occurs.

pub fn relative_to_cwd(self) -> Self

Attempt to print it out relative to the current working directory.

pub fn tilde<P: AsRef<Path> + ?Sized>(self, home: &'a P) -> Self

Abbreviate the path as ~ + separator + remainder when it is under home. Borrows home for the lifetime of this RichDisplay, so no allocation occurs.

pub fn tilde_me(self) -> Self

Abbreviate the path relative to the current user’s home directory.