pub struct BufferContents {
pub start: String,
pub end: Option<String>,
}Expand description
The finished contents of a BoundedBuffer.
Returned by BoundedBuffer::take.
Fields
start: StringThe start portion of the buffer’s contents.
If end is None, this contains the entire contents of the buffer.
end: Option<String>The end portion of the buffer’s contents.
If this is None, the buffer didn’t need any truncation, so the entire contents are in
start. If this is Some, there is a middle portion that was discarded.