pub struct Limit {
pub start: usize,
pub end: usize,
}Expand description
Controls how many bytes a BoundedBuffer can store.
Fields
start: usizeHow many bytes from the start of the buffer to keep.
end: usizeHow many bytes from the end of the buffer to keep.
Implementations