Module sync

Module sync 

Synchronization primitives.

Structs

EagerFuture
A cell whose value is seeded with a task scheduled at EagerFutureCell::new, in the background.

Traits

ResultCell
Acts as a storage backend to EagerFutureCell.

Type Aliases

AsyncShardedMutex
Sharded over tokio::sync::Mutex used purely as a lock (it guards (), carrying no value): lock is async, and its guard may be held across .awaits.
EagerFutureCell
A cell whose value is seeded with a task scheduled at EagerFutureCell::new, in the background.
MutEagerFutureCell
A cell whose value is seeded with a task scheduled at MutEagerFutureCell::new, in the background. Unlike the EagerFutureCell one-shot dual, MutEagerFutureCell allows you to emplace any arbitrary value into the cell, via the overwrite call.
ShardedMutex
Sharded over parking_lot::Mutex used purely as a lock (it guards (), carrying no value): lock blocks the calling thread, so never hold its guard across an .await.