pub struct RichDisplay<'a> { /* private fields */ }Expand description
A Display adapter for a path with optional enrichments, built via
DisplayRichExt::display_rich.
With no options set, the Display output is byte-identical to Path::display. You can also:
relative_to: if the path is underbase, render relative tobase.tilde: if the path is underhome, render it as~+ separator + remainder.trailing_slash: the rendered text ends with the platform separator.
Like Path::display, rendering is lossy for non-UTF-8 paths.
Implementations
Sourceimpl<'a> RichDisplay<'a>
impl<'a> RichDisplay<'a>
pub fn trailing_slash(self, enabled: bool) -> Self
Sourcepub fn relative_to<P: AsRef<Path> + ?Sized>(self, base: &'a P) -> Self
pub fn relative_to<P: AsRef<Path> + ?Sized>(self, base: &'a P) -> Self
Render the path relative to base when it is under it. Borrows base
for the lifetime of this RichDisplay, so no allocation occurs.
Sourcepub fn relative_to_cwd(self) -> Self
pub fn relative_to_cwd(self) -> Self
Attempt to print it out relative to the current working directory.