pub struct EnvDependentPathBuf {
pub primary: PathBuf,
pub envless: Option<PathBuf>,
}Expand description
An owned path that is dependent on environment variables.
This type is used as part of a workaround to handle the case where the daemon may have been
spawned in an environment with $TMPDIR unset, but where $TMPDIR is set when the client is
run. This type contains both paths the client needs to try to connect to.
Fields
primary: PathBufThe primary form of the path.
For example, $TMPDIR/example.txt.
envless: Option<PathBuf>The path that would be used if none of the relevant environment variables were set.
For example, /tmp/example.txt even when $TMPDIR is set.