String-related utilities and extension traits.
Re-exports
pub use bounded_buffer::BoundedBuffer;pub use trim::TrimExt;
Modules
- bounded_
buffer - highlighted
- Provides the
HighlightedTextutility which expresses the idea of a piece of text with highlight markers. - trim
Structs
- Blank
- The error returned when a string is empty or all whitespace.
- Contains
Nul - The error returned when a string contains a NUL byte.
- NonBlank
- A string with at least one non-whitespace character, held verbatim.
Tis any string type:String,&str,Cow<str>,Box<str>, … - NonNul
Str - A string proven to contain no NUL byte.
Traits
- Escape
NonPrintable Posix Ext - Extension trait for anything that can behave like a string to make it easy to
escape control characters into a printable,
cat -v-style representation. - Format
Safe UrlExt - Extension trait for
Urlto render aDebugrepresentation with any password redacted. - NonEmpty
OrExt - Extension trait for owned strings providing an empty-string fallback.
- Normalize
Diacritics Ext - Extension trait adding diacritic normalization to string slices.
- Truncate
Chars Ext
Functions
- normalize
- Normalize a Unicode character by converting Latin characters which are variants of ASCII characters to their latin equivalent.