pub type MutEagerFutureCell<T> = EagerFuture<Mutex<Option<T>>>;Expand description
A cell whose value is seeded with a task scheduled at MutEagerFutureCell::new, in the
background. Unlike the EagerFutureCell one-shot dual, MutEagerFutureCell allows you to
emplace any arbitrary value into the cell, via the overwrite call.
Aliased Type
pub struct MutEagerFutureCell<T> { /* private fields */ }